config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    rm $NEW
  fi
}

CONFIGS="slpkg.conf repositories.conf blacklist slackware-mirrors \
    default-repositories custom-repositories rlworkman.deps pkg_security"
for file in $CONFIGS; do
    config etc/slpkg/${file}.new
done

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi
